@@ -551,7 +551,7 @@ def _process_datasets(
     + """
 example usage:
 
-    eod-prepare s2-cophub S2A_OPER_PRD_MSIL1C_PDMC_20161017T123606_R018_V20161016T034742_20161016T034739.zip
+    eo3-prepare s2-cophub S2A_OPER_PRD_MSIL1C_PDMC_20161017T123606_R018_V20161016T034742_20161016T034739.zip
  --output . --no-checksum
 """
 )
