@@ -116,7 +116,7 @@ def add_lineage(lineage: Dict) -> Dict:
 
 def add_odc_links(explorer_base_url: str, dataset: DatasetDoc) -> List:
     """
-        Add links for ODC product into a STAC Item
+    Add links for ODC product into a STAC Item
     """
     if explorer_base_url:
         return [
@@ -151,7 +151,10 @@ def add_odc_links(explorer_base_url: str, dataset: DatasetDoc) -> List:
     nargs=-1,
 )
 def run(
-    odc_metadata_files: Iterable[Path], stac_base_url, explorer_base_url, validate,
+    odc_metadata_files: Iterable[Path],
+    stac_base_url,
+    explorer_base_url,
+    validate,
 ):
     for input_metadata in odc_metadata_files:
         dataset = serialise.from_path(input_metadata)
